UpgradeRequest

Struct UpgradeRequest 

#[non_exhaustive]
pub struct UpgradeRequest<E, B = ()> { pub key: Bytes, pub subprotocol: Option<String>, pub extension: Option<E>, pub request: Request<B>, pub extension_header: Option<HeaderValue>, }
Represents a parsed WebSocket connection upgrade HTTP request.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
key: Bytes

The security key provided by the client during the WebSocket handshake.

This key is used by the server to generate a response key, confirming that the server accepts the WebSocket upgrade request.

subprotocol: Option<String>

The optional WebSocket subprotocol agreed upon during the handshake.

The subprotocol is used to define the application-specific communication on top of the WebSocket connection, such as wamp or graphql-ws. If no subprotocol is requested or agreed upon, this will be None.

extension: Option<E>

The optional WebSocket extension negotiated during the handshake.

Extensions allow WebSocket connections to have additional functionality, such as compression or multiplexing. This field represents any such negotiated extension, or None if no extensions were negotiated.

request: Request<B>

The original HTTP request that initiated the WebSocket upgrade.

extension_header: Option<HeaderValue>

The optional Sec-WebSocket-Extensions header value from the HTTP request.

This header may contain the raw extension details sent by the client during the handshake. If no extension was requested, this field will be None.