UpgradeResponseParts

Struct UpgradeResponseParts 

#[non_exhaustive]
pub struct UpgradeResponseParts<E> { pub response: Response<()>, pub subprotocol: Option<String>, pub extension: Option<E>, }
A negotiated WebSocket response and its configured subprotcol and extension, if any.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
response: Response<()>

An http::Response<()>, which represents the WebSocket handshake response.

subprotocol: Option<String>

The optional WebSocket subprotocol agreed upon during the handshake.

The subprotocol is used to define the application-specific communication on top of the WebSocket connection, such as wamp or graphql-ws. If no subprotocol is requested or agreed upon, this will be None.

extension: Option<E>

The optional WebSocket extension negotiated during the handshake.

Extensions allow WebSocket connections to have additional functionality, such as compression or multiplexing. This field represents any such negotiated extension, or None if no extensions were negotiated.